<?php

/**
 * CS-Cart Advanced RMA - ec_advanced_rma
 * 
 * PHP version 8.1
 * 
 * @category  Add-on
 * @package   CS_Cart
 * @author    Ecarter Technologies Private Limited <support@ecarter.co>
 * @copyright 2021 Ecarter Technologies Private Limited
 * @license   http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

use Tygh\Registry;

if (!defined('BOOTSTRAP')) {
    die('Access denied');
}

function fn_settings_variants_addons_ec_advanced_rma_damaged_product_reason()
{
    $data = array(
        '' => ' -- '
    );
    $rma_reasons = fn_get_rma_properties('R');
    foreach ($rma_reasons as $rma_reason) {
        $data[$rma_reason['property_id']] = $rma_reason['property'];
    }
    return $data;
}

function fn_settings_variants_addons_ec_advanced_rma_partially_damaged_product_reason()
{
    $data = array(
        '' => ' -- '
    );
    $rma_reasons = fn_get_rma_properties('R');
    foreach ($rma_reasons as $rma_reason) {
        $data[$rma_reason['property_id']] = $rma_reason['property'];
    }
    return $data;
}

function fn_ec_advanced_rma_add_damaged_product($rma_data)
{
    $return_data = db_get_row("SELECT ?:rma_returns.* FROM ?:rma_returns WHERE ?:rma_returns.return_id = ?i", $rma_data['change_return_status']['return_id']);
    $damaged_product_reason = Registry::get('addons.ec_advanced_rma.damaged_product_reason');
    $partially_damaged_product_reason = Registry::get('addons.ec_advanced_rma.partially_damaged_product_reason');

    if (!empty($rma_data['accepted']) && !empty($return_data) && !empty($rma_data['change_return_status']['action']) && $rma_data['change_return_status']['action'] === '1') {
        foreach ($rma_data['accepted'] as $accepted) {
            if (!empty($damaged_product_reason) && !empty($partially_damaged_product_reason) && ($accepted['ec_reason_id'] == $damaged_product_reason || $accepted['ec_reason_id'] == $partially_damaged_product_reason)) {

                $product_info = db_get_row("SELECT ?:products.partially_damaged_quantity, ?:products.damaged_quantity, ?:products.amount FROM ?:products WHERE ?:products.product_id = ?i ", $accepted['product_id']);

                if ($product_info['amount'] < $accepted['previous_amount']) {
                    db_query("UPDATE ?:rma_returns SET status = ?s WHERE return_id = ?i", $_REQUEST['change_return_status']['status_from'], $rma_data['change_return_status']['return_id']);
                    fn_set_notification('W', __('warning'), __('ec_advanced_rma.product_amount_error'));
                    fn_redirect(fn_url('rma.details&return_id=' . $_REQUEST['change_return_status']['return_id']));
                    return false;
                }
            }
        }
    }

    if (!empty($rma_data['accepted']) && !empty($return_data)) {
        foreach ($rma_data['accepted'] as $accepted) {

            if (!empty($damaged_product_reason) && !empty($partially_damaged_product_reason) && ($accepted['ec_reason_id'] == $damaged_product_reason || $accepted['ec_reason_id'] == $partially_damaged_product_reason)) {

                if ($accepted['ec_reason_id'] == $partially_damaged_product_reason) {
                    $column_name = 'partially_damaged_quantity';
                } elseif ($accepted['ec_reason_id'] == $damaged_product_reason) {
                    $column_name = 'damaged_quantity';
                }
                $update_value = '';
                if (!empty($rma_data['change_return_status']['action']) && $rma_data['change_return_status']['action'] === '1') {
                    $update_value .= ', amount = amount - ' . $accepted['previous_amount'];
                }

                db_query('UPDATE ?:products SET ' . $column_name . ' = ' . $column_name . '+ ?i' . $update_value . ' WHERE product_id = ?i', $accepted['previous_amount'], $accepted['product_id']);
            }
        }
    }
}

function fn_ec_advanced_rma_remove_damaged_product($rma_data)
{
    $return_data = db_get_row("SELECT ?:rma_returns.* FROM ?:rma_returns WHERE ?:rma_returns.return_id = ?i", $rma_data['change_return_status']['return_id']);
    $damaged_product_reason = Registry::get('addons.ec_advanced_rma.damaged_product_reason');
    $partially_damaged_product_reason = Registry::get('addons.ec_advanced_rma.partially_damaged_product_reason');

    if (!empty($rma_data['accepted']) && !empty($return_data)) {
        foreach ($rma_data['accepted'] as $accepted) {
            if (!empty($damaged_product_reason) && !empty($partially_damaged_product_reason) && ($accepted['ec_reason_id'] == $damaged_product_reason || $accepted['ec_reason_id'] == $partially_damaged_product_reason)) {
                $product_info = db_get_row("SELECT ?:products.partially_damaged_quantity, ?:products.damaged_quantity, ?:products.amount FROM ?:products WHERE ?:products.product_id = ?i ", $accepted['product_id']);

                if ($accepted['ec_reason_id'] == $partially_damaged_product_reason) {
                    $column_name = 'partially_damaged_quantity';
                    if (empty($product_info['partially_damaged_quantity'])) {
                        continue;
                    }
                } elseif ($accepted['ec_reason_id'] == $damaged_product_reason) {
                    $column_name = 'damaged_quantity';
                    if (empty($product_info['damaged_quantity'])) {
                        continue;
                    }
                }
                $update_value = '';
                if (!empty($rma_data['change_return_status']['action']) && $rma_data['change_return_status']['action'] === '1') {
                    $update_value .= ', amount = amount + ' . $accepted['previous_amount'];
                }
                db_query('UPDATE ?:products SET ' . $column_name . ' = ' . $column_name . '- ?i' . $update_value . ' WHERE product_id = ?i', $accepted['previous_amount'], $accepted['product_id']);
            }
        }
    }
}

function fn_ec_advanced_rma_get_products($params, &$fields, $sortings, &$condition, $join, $sorting, $group_by, $lang_code, $having)
{
    if (!empty($params['ec_advanced_rma'])) {
        $fields['damaged_quantity'] = 'products.damaged_quantity';
        $fields['partially_damaged_quantity'] = 'products.partially_damaged_quantity';
        $condition .= ' AND (products.partially_damaged_quantity > 0 OR products.damaged_quantity > 0)';
    }
}
